@@ -35,6 +35,8 @@ jobWorkingDirectory=$1
 jobScratchDirectory=$2
 jobClass=$3
 
+sharedFileSystem=1
+
 exitStatus=0
 if [ ${jobClass} = PEGASUS ] ; then
    if [ ${jobScratchDirectory} != ${jobWorkingDirectory} ] ; then
@@ -50,8 +52,10 @@ if [ ${jobClass} = PEGASUS ] ; then
       fi
    fi
 else
-   rm -rf ${jobWorkingDirectory}
-   exitStatus=$?
+   if [ ${sharedFileSystem} -ne 1 ] ; then
+      rm -rf ${jobWorkingDirectory}
+      exitStatus=$?
+   fi
 fi
 
 exit ${exitStatus}
