@@ -42,7 +42,7 @@ def isGroupMember(groupName):
       _,_,requestedGroupId,_ = grp.getgrnam(groupName)
    except:
       logger = logging.getLogger(__name__)
-      logger(logging.ERROR,getLogMessage("Unable to get gid of '%s'" % (groupName)))
+      logger.log(logging.ERROR,getLogMessage("Unable to get gid of '%s'" % (groupName)))
       return False
 
    for groupId in os.getgroups():
