@@ -1,10 +1,10 @@
 # @package      hubzero-submit-distributor
 # @file         VenueMechanismSsh.py
 # @author       Steven Clark <clarks@purdue.edu>
-# @copyright    Copyright (c) 2012-2013 HUBzero Foundation, LLC.
+# @copyright    Copyright (c) 2012-2014 HUBzero Foundation, LLC.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
-# Copyright (c) 2012-2013 HUBzero Foundation, LLC.
+# Copyright (c) 2012-2014 HUBzero Foundation, LLC.
 #
 # This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 #
@@ -32,10 +32,11 @@ import stat
 import time
 import datetime
 import shutil
+import logging
 
-from hubzero.submit.LogMessage             import logID as log
+from hubzero.submit.LogMessage             import getLogIDMessage as getLogMessage
 from hubzero.submit.JobStatistic           import JobStatistic
-from hubzero.submit.JobOutput              import *
+from hubzero.submit.JobOutput              import JobOutput
 from hubzero.submit.VenueMechanismCore     import VenueMechanismCore
 from hubzero.submit.RemoteBatchCONDOR      import RemoteBatchCONDOR
 from hubzero.submit.RemoteBatchRUNJOB      import RemoteBatchRUNJOB
@@ -96,6 +97,8 @@ class VenueMechanismSsh(VenueMechanismCore):
       VenueMechanismCore.__init__(self,timeHistoryLogs,siteInfo,managerInfo,remoteMonitors,
                                        isMultiCoreRequest,nCpus,nNodes,ppn)
 
+      self.logger                           = logging.getLogger(__name__)
+      self.jobOutput                        = JobOutput()
       self.venueMechanism                   = 'ssh'
       self.hubUserName                      = hubUserName
       self.hubUserId                        = hubUserId
@@ -218,21 +221,21 @@ class VenueMechanismSsh(VenueMechanismCore):
             keyfamily = self.remoteUser.split(':')[1]
             self.remoteUser = self.hubUserName
             command = 'genuserpki ' + keyfamily
-            log("command = " + command)
+            self.logger.log(logging.INFO,getLogMessage("command = " + command))
             exitStatus,stdOutput,stdError = self.executeCommand(command)
             if not exitStatus:
                self.sshIdentityPath = stdOutput.strip()
-               log("IDENTITY = " + self.sshIdentityPath)
+               self.logger.log(logging.INFO,getLogMessage("IDENTITY = " + self.sshIdentityPath))
                updateKnownHosts = True
          elif self.remoteUser.startswith('USER'):
             self.remoteUser = self.hubUserName
          else:
             command = 'genuserid'
-            log("command = " + command)
+            self.logger.log(logging.INFO,getLogMessage("command = " + command))
             exitStatus,stdOutput,stdError = self.executeCommand(command)
             if not exitStatus:
                self.sshIdentityPath = stdOutput.strip()
-               log("IDENTITY = " + self.sshIdentityPath)
+               self.logger.log(logging.INFO,getLogMessage("IDENTITY = " + self.sshIdentityPath))
                updateKnownHosts = True
                if self.sshIdentityPath:
                   self.removeIdentity = True
@@ -241,16 +244,16 @@ class VenueMechanismSsh(VenueMechanismCore):
             if updateKnownHosts:
                if self.tunnelDesignator == "":
                   command = 'update-known-hosts' + " " + self.venue
-                  log("command = " + command)
+                  self.logger.log(logging.INFO,getLogMessage("command = " + command))
                   exitStatus,stdOutput,stdError = self.executeCommand(command)
                else:
                   if self.gatewayHost != "" and self.localHost != "":
                      command = 'update-known-hosts' + " \'" + self.gatewayHost + "\'"
-                     log("command = " + command)
+                     self.logger.log(logging.INFO,getLogMessage("command = " + command))
                      exitStatus,stdOutput,stdError = self.executeCommand(command)
                      if not exitStatus:
                         command = 'update-known-hosts' + " \'" + self.localHost + "\'"
-                        log("command = " + command)
+                        self.logger.log(logging.INFO,getLogMessage("command = " + command))
                         exitStatus,stdOutput,stdError = self.executeCommand(command)
                if not exitStatus:
                   if self.tunnelDesignator == "":
@@ -269,7 +272,7 @@ class VenueMechanismSsh(VenueMechanismCore):
       scriptFiles = []
 
       if self.sshBaseCommand != "":
-         log("workingDirectory " + self.workingDirectory)
+         self.logger.log(logging.INFO,getLogMessage("workingDirectory " + self.workingDirectory))
          if   self.remoteBatchSystem == 'PBS':
             remoteAppScript = RemoteBatchAppScript(self.hubUserName,self.hubUserId,
                                                    self.runName,self.localJobId,self.instanceId,False,
@@ -489,16 +492,16 @@ class VenueMechanismSsh(VenueMechanismCore):
                   submissionAllowed,executableClassification = self.appsAccessInfo.isSubmissionAllowed(userDaxExecutable)
                   if not submissionAllowed:
                      message = "Access to %s denied for %s" % (userDaxExecutable,self.hubUserName)
-                     log(message)
-                     self.__writeToStderr(message + "\n")
+                     self.logger.log(logging.ERROR,getLogMessage(message))
+                     self._writeToStderr(message + "\n")
                      if not exitCode:
                         exitCode = 9
                   if (not '*' in self.executableClassificationsAllowed) and \
                      (not executableClassification in self.executableClassificationsAllowed):
                      message = "The selected site does not meet the specified\n" + \
                                "application access requirements.  Please select another site."
-                     log(message)
-                     self.__writeToStderr(message + "\n")
+                     self.logger.log(logging.ERROR,getLogMessage(message))
+                     self._writeToStderr(message + "\n")
                      if not exitCode:
                         exitCode = 10
          elif self.remoteBatchSystem == 'SCRIPT':
@@ -565,8 +568,8 @@ class VenueMechanismSsh(VenueMechanismCore):
                elif self.remoteBatchSystem == 'PEGASUS':
                   os.chmod(self.batchScriptPath,stat.S_IRWXU|stat.S_IRGRP|stat.S_IXGRP|stat.S_IROTH|stat.S_IXOTH)
             else:
-               log("could not open %s for writing" % (self.batchScriptPath))
-               self.__writeToStderr("could not open %s for writing\n" % (self.batchScriptPath))
+               self.logger.log(logging.ERROR,getLogMessage("could not open %s for writing" % (self.batchScriptPath)))
+               self._writeToStderr("could not open %s for writing\n" % (self.batchScriptPath))
                self.jobStatistics[0]['exitCode'] = 1
                exitCode = 1
 
@@ -578,8 +581,8 @@ class VenueMechanismSsh(VenueMechanismCore):
                os.chmod(self.appScriptPath,stat.S_IRWXU|stat.S_IRGRP|stat.S_IXGRP|stat.S_IROTH|stat.S_IXOTH)
                scriptFiles.append(self.appScriptPath)
             else:
-               log("could not open %s for writing" % (self.appScriptPath))
-               self.__writeToStderr("could not open %s for writing\n" % (self.appScriptPath))
+               self.logger.log(logging.ERROR,getLogMessage("could not open %s for writing" % (self.appScriptPath)))
+               self._writeToStderr("could not open %s for writing\n" % (self.appScriptPath))
                self.jobStatistics[0]['exitCode'] = 1
                exitCode = 1
 
@@ -589,8 +592,8 @@ class VenueMechanismSsh(VenueMechanismCore):
                fpNodes.write('\n'.join(nodeList)+'\n')
                fpNodes.close()
             else:
-               log("could not open %s for writing" % (self.nodeFilePath))
-               self.__writeToStderr("could not open %s for writing\n" % (self.nodeFilePath))
+               self.logger.log(logging.ERROR,getLogMessage("could not open %s for writing" % (self.nodeFilePath)))
+               self._writeToStderr("could not open %s for writing\n" % (self.nodeFilePath))
                self.jobStatistics[0]['exitCode'] = 1
                exitCode = 1
       else:
@@ -624,9 +627,9 @@ class VenueMechanismSsh(VenueMechanismCore):
                                                                 remoteWorkingDirectory + " " + \
                                                                 remoteScratchDirectory + " " + \
                                                                 self.timeHistoryLogs['timestampTransferred'] + "\""
-               log("command = " + command)
+               self.logger.log(logging.INFO,getLogMessage("command = " + command))
                exitStatus,stdOutput,stdError = self.executeSSHCommand(command,self.tunnelDesignator)
-               log(stdOutput)
+               self.logger.log(logging.INFO,getLogMessage(stdOutput))
             else:
                exitStatus = 1
                stdOutput  = ""
@@ -643,9 +646,9 @@ class VenueMechanismSsh(VenueMechanismCore):
                                                        remoteWorkingDirectory + " " + \
                                                        remoteScratchDirectory + " " + \
                                                        self.timeHistoryLogs['timestampTransferred'] + "\""
-               log("command = " + command)
+               self.logger.log(logging.INFO,getLogMessage("command = " + command))
                exitStatus,stdOutput,stdError = self.executeSSHCommand(command,self.tunnelDesignator)
-               log(stdOutput)
+               self.logger.log(logging.INFO,getLogMessage(stdOutput))
             else:
                exitStatus = 1
                stdOutput  = ""
@@ -657,13 +660,19 @@ class VenueMechanismSsh(VenueMechanismCore):
          if exitStatus:
             self.filesSent = False
 #           if stdOutput != "":
-#              stdFile = os.path.join(self.instanceDirectory,"%s_%s.stdout" % (self.localJobId,self.instanceId))
+#              if self.instanceId:
+#                 stdFile = os.path.join(self.instanceDirectory,"%s_%s.stdout" % (self.runName,self.instanceId))
+#              else:
+#                 stdFile = os.path.join(self.instanceDirectory,"%s.stdout" % (self.runName))
 #              fpStd = open(stdFile,'a')
 #              if fpStd:
 #                 fpStd.write(stdOutput)
 #                 fpStd.close()
             if stdError != "":
-               stdFile = os.path.join(self.instanceDirectory,"%s_%s.stderr" % (self.localJobId,self.instanceId))
+               if self.instanceId:
+                  stdFile = os.path.join(self.instanceDirectory,"%s_%s.stderr" % (self.runName,self.instanceId))
+               else:
+                  stdFile = os.path.join(self.instanceDirectory,"%s.stderr" % (self.runName))
                fpStd = open(stdFile,'a')
                if fpStd:
                   fpStd.write(stdError)
@@ -694,7 +703,7 @@ class VenueMechanismSsh(VenueMechanismCore):
                commandArgs.append(self.executable)
             command = self.sshBaseCommand + " \"" + ' '.join(commandArgs) + "\""
 
-            log("command = " + command)
+            self.logger.log(logging.INFO,getLogMessage("command = " + command))
             exitStatus,stdOutput,stdError = self.executeSSHCommand(command,self.tunnelDesignator,True)
             self.jobSubmitted = True
             self.jobStatistics[self.jobIndex]['exitCode'] = exitStatus
@@ -703,7 +712,7 @@ class VenueMechanismSsh(VenueMechanismCore):
                command = self.sshBaseCommand + " " + self.batchScriptPath
             else:
                command = self.sshBaseCommand + " " + self.appScriptPath
-            log("command = " + command)
+            self.logger.log(logging.INFO,getLogMessage("command = " + command))
             exitStatus,stdOutput,stdError = self.executeCommand(command,True)
             self.jobSubmitted = True
             self.jobStatistics[self.jobIndex]['exitCode'] = exitStatus
@@ -726,11 +735,11 @@ class VenueMechanismSsh(VenueMechanismCore):
                commandArgs.append(self.executable)
             command = self.sshBaseCommand + " \"" + ' '.join(commandArgs) + "\""
 
-            log("command = " + command)
+            self.logger.log(logging.INFO,getLogMessage("command = " + command))
             exitStatus,stdOutput,stdError = self.executeSSHCommand(command,self.tunnelDesignator)
             if not exitStatus:
                remoteJobId = stdOutput.strip()
-               log("remoteJobId = " + remoteJobId)
+               self.logger.log(logging.INFO,getLogMessage("remoteJobId = " + remoteJobId))
                self.jobSubmitted = True
                self.remoteJobIdNumber = remoteJobId
 
@@ -759,12 +768,12 @@ class VenueMechanismSsh(VenueMechanismCore):
                commandArgs.append(self.localJobId.lstrip('0') + '_' + self.instanceId)
                commandArgs.append(self.executable)
             command = self.sshBaseCommand + " \"" + ' '.join(commandArgs) + "\""
-            log("command = " + command)
+            self.logger.log(logging.INFO,getLogMessage("command = " + command))
             exitStatus,stdOutput,stdError = self.executeSSHCommand(command,self.tunnelDesignator)
 
             if not exitStatus:
                remoteJobId = stdOutput.strip()
-               log("remoteJobId = " + remoteJobId)
+               self.logger.log(logging.INFO,getLogMessage("remoteJobId = " + remoteJobId))
                try:
                   if   self.remoteBatchSystem == 'PBS':
                      self.remoteJobIdNumber = remoteJobId.split('.')[0]
@@ -825,12 +834,12 @@ class VenueMechanismSsh(VenueMechanismCore):
             commandArgs.append(remoteScratchDirectory)
             commandArgs.append(os.path.join('.',os.path.basename(self.batchScriptPath)))
             command = self.sshBaseCommand + " \"" + ' '.join(commandArgs) + "\""
-            log("command = " + command)
+            self.logger.log(logging.INFO,getLogMessage("command = " + command))
             exitStatus,stdOutput,stdError = self.executeSSHCommand(command,self.tunnelDesignator)
 
             if not exitStatus:
                remoteJobId = stdOutput.strip()
-               log("remoteJobId = " + remoteJobId)
+               self.logger.log(logging.INFO,getLogMessage("remoteJobId = " + remoteJobId))
                try:
                   if   self.remoteBatchSystem == 'PBS':
                      self.remoteJobIdNumber = remoteJobId.split('.')[0]
@@ -882,13 +891,19 @@ class VenueMechanismSsh(VenueMechanismCore):
 
       if not self.jobSubmitted:
          if stdOutput != "":
-            stdFile = os.path.join(self.instanceDirectory,"%s_%s.stdout" % (self.localJobId,self.instanceId))
+            if self.instanceId:
+               stdFile = os.path.join(self.instanceDirectory,"%s_%s.stdout" % (self.runName,self.instanceId))
+            else:
+               stdFile = os.path.join(self.instanceDirectory,"%s.stdout" % (self.runName))
             fpStd = open(stdFile,'a')
             if fpStd:
                fpStd.write(stdOutput)
                fpStd.close()
          if stdError != "":
-            stdFile = os.path.join(self.instanceDirectory,"%s_%s.stderr" % (self.localJobId,self.instanceId))
+            if self.instanceId:
+               stdFile = os.path.join(self.instanceDirectory,"%s_%s.stderr" % (self.runName,self.instanceId))
+            else:
+               stdFile = os.path.join(self.instanceDirectory,"%s.stderr" % (self.runName))
             fpStd = open(stdFile,'a')
             if fpStd:
                fpStd.write(stdError)
@@ -921,8 +936,8 @@ class VenueMechanismSsh(VenueMechanismCore):
                                                           remoteWorkingDirectory + " " + \
                                                           remoteScratchDirectory + " " + \
                                                           "PEGASUS" + "\""
-                  log("command = " + command)
-                  log(self.executeSSHCommand(command,self.tunnelDesignator)[1])
+                  self.logger.log(logging.INFO,getLogMessage("command = " + command))
+                  self.logger.log(logging.INFO,getLogMessage(self.executeSSHCommand(command,self.tunnelDesignator)[1]))
 
                   self.jobPostProcessed = True
 
@@ -936,19 +951,25 @@ class VenueMechanismSsh(VenueMechanismCore):
             if self.jobSubmitted:
                command = self.sshBaseCommand + " \"" + self.transmitResults + " " + remoteWorkingDirectory + "\"" + \
                                                " | tar xzmf - --ignore-case --exclude '*hub-proxy.*' -C " + self.instanceDirectory
-               log("command = " + command)
+               self.logger.log(logging.INFO,getLogMessage("command = " + command))
                exitStatus,stdOutput,stdError = self.executeSSHCommand(command,self.tunnelDesignator)
-               log(stdOutput)
+               self.logger.log(logging.INFO,getLogMessage(stdOutput))
                if exitStatus:
                   self.jobStatistics[self.jobIndex]['exitCode'] = 12
 #                  if stdOutput != "":
-#                     stdFile = os.path.join(self.instanceDirectory,"%s_%s.stdout" % (self.localJobId,self.instanceId))
+#                     if self.instanceId:
+#                        stdFile = os.path.join(self.instanceDirectory,"%s_%s.stdout" % (self.runName,self.instanceId))
+#                     else:
+#                        stdFile = os.path.join(self.instanceDirectory,"%s.stdout" % (self.runName))
 #                     fpStd = open(stdFile,'a')
 #                     if fpStd:
 #                        fpStd.write(stdOutput)
 #                        fpStd.close()
                   if stdError != "":
-                     stdFile = os.path.join(self.instanceDirectory,"%s_%s.stderr" % (self.localJobId,self.instanceId))
+                     if self.instanceId:
+                        stdFile = os.path.join(self.instanceDirectory,"%s_%s.stderr" % (self.runName,self.instanceId))
+                     else:
+                        stdFile = os.path.join(self.instanceDirectory,"%s.stderr" % (self.runName))
                      fpStd = open(stdFile,'a')
                      if fpStd:
                         fpStd.write(stdError)
@@ -970,24 +991,30 @@ class VenueMechanismSsh(VenueMechanismCore):
                   else:
                      command = "tar xmf " + stageOutTarFile + \
                                         " --ignore-case --exclude '*hub-proxy.*' -C " + self.instanceDirectory
-                  log("command = " + command)
+                  self.logger.log(logging.INFO,getLogMessage("command = " + command))
                   exitStatus,stdOutput,stdError = self.executeCommand(command)
                   if exitStatus == 0:
                      os.remove(stageOutTarFile)
                   else:
-                     log(stdOutput)
+                     self.logger.log(logging.ERROR,getLogMessage(stdOutput))
                   break
 
             if exitStatus:
                self.jobStatistics[self.jobIndex]['exitCode'] = 12
 #              if stdOutput != "":
-#                 stdFile = os.path.join(self.instanceDirectory,"%s_%s.stdout" % (self.localJobId,self.instanceId))
+#                 if self.instanceId:
+#                    stdFile = os.path.join(self.instanceDirectory,"%s_%s.stdout" % (self.runName,self.instanceId))
+#                 else:
+#                    stdFile = os.path.join(self.instanceDirectory,"%s.stdout" % (self.runName))
 #                 fpStd = open(stdFile,'a')
 #                 if fpStd:
 #                    fpStd.write(stdOutput)
 #                    fpStd.close()
                if stdError != "":
-                  stdFile = os.path.join(self.instanceDirectory,"%s_%s.stderr" % (self.localJobId,self.instanceId))
+                  if self.instanceId:
+                     stdFile = os.path.join(self.instanceDirectory,"%s_%s.stderr" % (self.runName,self.instanceId))
+                  else:
+                     stdFile = os.path.join(self.instanceDirectory,"%s.stderr" % (self.runName))
                   fpStd = open(stdFile,'a')
                   if fpStd:
                      fpStd.write(stdError)
@@ -1006,8 +1033,8 @@ class VenueMechanismSsh(VenueMechanismCore):
                command = "cleanupkilled.sh " + self.remoteBatchSystem + " " + \
                                                workDirectoryName + " " + \
                                                self.timeHistoryLogs['jobGridJobId']
-               log("command = " + command)
-               log(self.executeCommand(command)[1])
+               self.logger.log(logging.INFO,getLogMessage("command = " + command))
+               self.logger.log(logging.INFO,getLogMessage(self.executeCommand(command)[1]))
             if self.jobSubmitted:
                self.recordGridResourceUse()
                self.logGridJobId()
@@ -1024,20 +1051,20 @@ class VenueMechanismSsh(VenueMechanismCore):
                   remoteScratchDirectory = self.scratchDirectory.replace('$','\$')
 
                   if self.isParametric:
-                     getPegasusStdTimeFiles(self.instanceDirectory,
-                                            self.scratchDirectory,
-                                            self.timeHistoryLogs['timeResults'])
+                     self.jobOutput.getPegasusStdTimeFiles(self.instanceDirectory,
+                                                           self.scratchDirectory,
+                                                           self.timeHistoryLogs['timeResults'])
                   else:
-                     processPegasusFiles(self.instanceDirectory,
-                                         self.scratchDirectory,
-                                         self.timeHistoryLogs['timeResults'])
+                     self.jobOutput.processPegasusFiles(self.instanceDirectory,
+                                                        self.scratchDirectory,
+                                                        self.timeHistoryLogs['timeResults'])
 
                   command = self.sshBaseCommand + " \"" + self.cleanupJob + " " + \
                                                           remoteWorkingDirectory + " " + \
                                                           remoteScratchDirectory + " " + \
                                                           self.remoteBatchSystem + "\""
-                  log("command = " + command)
-                  log(self.executeSSHCommand(command,self.tunnelDesignator)[1])
+                  self.logger.log(logging.INFO,getLogMessage("command = " + command))
+                  self.logger.log(logging.INFO,getLogMessage(self.executeSSHCommand(command,self.tunnelDesignator)[1]))
 
             workDirectoryName = os.path.join(self.instanceDirectory,'work')
             if os.path.isdir(workDirectoryName):
@@ -1070,8 +1097,8 @@ class VenueMechanismSsh(VenueMechanismCore):
                                                           remoteWorkingDirectory + " " + \
                                                           remoteScratchDirectory + " " + \
                                                           self.remoteBatchSystem + "\""
-                  log("command = " + command)
-                  log(self.executeSSHCommand(command,self.tunnelDesignator)[1])
+                  self.logger.log(logging.INFO,getLogMessage("command = " + command))
+                  self.logger.log(logging.INFO,getLogMessage(self.executeSSHCommand(command,self.tunnelDesignator)[1]))
             elif self.sharedUserSpace and self.stageFiles:
                stageOutTarFile = "%s_%s_output.tar.gz" % (self.localJobId,self.instanceId)
                if os.path.isfile(stageOutTarFile):
@@ -1107,8 +1134,8 @@ class VenueMechanismSsh(VenueMechanismCore):
             self.logGridHistories()
          command = self.sshBaseCommand + \
                    " \"" + self.killBatchJob + " " + self.remoteJobIdNumber + " " + self.remoteBatchSystem + "\""
-         log("command = " + command)
-         log(self.executeSSHCommand(command,self.tunnelDesignator)[1])
+         self.logger.log(logging.INFO,getLogMessage("command = " + command))
+         self.logger.log(logging.INFO,getLogMessage(self.executeSSHCommand(command,self.tunnelDesignator)[1]))
       elif self.remoteBatchSystem == 'SCRIPT' and self.childPid != 0:
 #        log("Send TERM to child script process %d" % (self.childPid))
 #        os.kill(childPid,signalNumber.SIGTERM)
@@ -1116,21 +1143,21 @@ class VenueMechanismSsh(VenueMechanismCore):
             command = self.sshBaseCommand + " pkill -TERM -f " + os.path.basename(self.batchScriptPath)
          else:
             command = self.sshBaseCommand + " pkill -TERM -f " + os.path.basename(self.appScriptPath)
-         log("command = " + command)
-         log(self.executeSSHCommand(command,self.tunnelDesignator)[1])
+         self.logger.log(logging.INFO,getLogMessage("command = " + command))
+         self.logger.log(logging.INFO,getLogMessage(self.executeSSHCommand(command,self.tunnelDesignator)[1]))
 
          if self.batchScriptPath != "":
             command = self.sshBaseCommand + " pkill -0 -f " + os.path.basename(self.batchScriptPath)
          else:
             command = self.sshBaseCommand + " pkill -0 -f " + os.path.basename(self.appScriptPath)
-         log("command = " + command)
+         self.logger.log(logging.INFO,getLogMessage("command = " + command))
          statusCode = self.executeSSHCommand(command,self.tunnelDesignator)[0]
          while statusCode == 0:
             time.sleep(2)
             statusCode = self.executeSSHCommand(command,self.tunnelDesignator)[0]
 
       maximumJobIndex = max(self.jobStatistics.keys())
-      self.jobStatistics[maximumJobIndex]['exitCode'] = 1 << 8 | signalNumber
+      self.jobStatistics[maximumJobIndex]['exitCode'] = 1 << 7 | signalNumber
 
       self.scriptsKilled = True
 
